#define BUILD_NUMBER \
	"build-16938113"
#define BUILD_NUMBER_NUMERIC \
	16938113
#define BUILD_NUMBER_NUMERIC_STRING \
	"16938113"
#define PRODUCT_BUILD_NUMBER \
	"product-build-23855"
#define PRODUCT_BUILD_NUMBER_NUMERIC \
	23855
#define PRODUCT_BUILD_NUMBER_NUMERIC_STRING \
	"23855"
